Crate iota_sc_hname_generator
iota_
sc_
hname_
generator
1.1.6
All Items
Crate Items
Macros
Crate
iota_
sc_
hname_
generator
Macros

generate_
hash
Calculates hash of the input string and generates the output: “0x123ABC”
generate_
schname
Calculates hash of the input string and generates the output: “ScHname(<generated hash>);”